pub trait ReadStorage {
type Error;
// Required methods
async fn read(
&mut self,
offset: u32,
bytes: &mut [u8],
) -> Result<(), Self::Error>;
fn capacity(&self) -> usize;
}Expand description
Transparent read only storage trait
Required Associated Types
Required Methods
Sourceasync fn read(
&mut self,
offset: u32,
bytes: &mut [u8],
) -> Result<(), Self::Error>
async fn read( &mut self, offset: u32, bytes: &mut [u8], ) -> Result<(), Self::Error>
Read a slice of data from the storage peripheral, starting the read
operation at the given address offset, and reading bytes.len() bytes.
This should throw an error in case bytes.len() will be larger than
self.capacity() - offset.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".